# React Dropdown

This package provides a dropdown component and example styles (`scss` and `css`).

## Installation

You can install this packge with either `npm` or `yarn`.

```
npm i @ninetynine/react-dropdown
```
<small><i>An example of how to install the package through NPM.</i></small>

```
yarn add @ninetynine/react-dropdown
```
<small><i>An example of how to install the package through Yarn.</i></small>

Be sure to import the styles into your main style file or into your HTML, and import the component if you wish to use it within your project.

```
import "~@ninetynine/dropdown/dist/dropdown"
```
<small><i>An example of how to import into `scss`.</i></small>

## Usage
After importing the styles and component into your project you'll be able to use the `<Dropdown />` component.

By default the component will not have any menu items, so it displays an empty message: "No Options Found". `<Dropdown />` will bind itself to any single child passed into it using `onClick`.

```jsx
<Dropdown>
	<a>I now can toggle the dropdown onClick</a>
</Dropdown>
```
<small><i>A minimal example for basic usage.</i></small>

### Passing list items into the dropdown
By default there are no `menuItems` passed into `<Dropdown />`. `menuItems` accepts an array of shapes: `{ content; onClick; }`. `content` being a valid React element and `onClick` being a function.

```jsx
<Dropdown
	menuItems={[
		{
			content: 'Hello, world',
			onClick: this.handleClick
		}
	]}
>
	<a>I now can toggle the dropdown onClick</a>
</Dropdown>
```
<small><i>A minimal example of passing a string into a menu item.</i></small>

```jsx
<Dropdown
	menuItems={[
		{
			content: (
				<p>Hello, world</p>
			),
			onClick: this.handleClick
		}
	]}
>
	<a>I now can toggle the dropdown onClick</a>
</Dropdown>
```
<small><i>A minimal example of passing a valid React Element into a menu item.</i></small>

### Changing the empty message
If no `menuItems` are passed into `<Dropdown />` then it will display an empty message. By default this empty message reads: "No Options Found", you can change this using the `emptyMessage` prop which accepts a valid React element.

```jsx
<Dropdown
	emptyMessage={'Custom Empty Message'}
>
	<a>I now can toggle the dropdown onClick</a>
</Dropdown>
```
<small><i>An example of how to change the empty message with a string.</i></small>



```jsx
<Dropdown
	emptyMessage={(
		<Flex row>
			<p>Hello, world</p>
		</Flex>
	)}
>
	<a>I now can toggle the dropdown onClick</a>
</Dropdown>
```
<small><i>An example of how to change the empty message with valid React elements.</i></small>

### Adding custom styles and class names to `<Dropdown />`
`<Dropdown />` has the props style and className that directly alter the styles and classes of the containing element. These work the same way as they would on a standard HTML element.

_It's worth noting that className will append classes to the already default `<Dropdown />` classes._

---

#### Other useful packages
- [@ninetynine/react-flex](https://github.com/ninetynine/react-flex)
- [@ninetynine/react-react-dynamic-form-select](https://github.com/ninetynine/react-dynamic-form-select)
- [@ninetynine/react-react-dynamic-form-datepicker](https://github.com/ninetynine/react-dynamic-form-datepicker)
- [@langleyfoxall/react-dynamic-data-table](https://github.com/langleyfoxall/react-dynamic-data-table)
- [@langleyfoxall/react-dynamic-form-builder](https://github.com/langleyfoxall/react-dynamic-form-builder)
- [@langleyfoxall/react-dynamic-context-menu](https://github.com/langleyfoxall/react-dynamic-context-menu)
- [@langleyfoxall/react-click-outside](https://github.com/langleyfoxall/react-click-outside)